/*------------ Telecommunications & Signal Processing Lab --------------
                         McGill University

Routine:
  SunPlay.h

Description:
  Declarations for SunPlay

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.24 $  $Date: 1999/06/14 16:30:03 $

----------------------------------------------------------------------*/

#ifndef SunPlay_h_
#define SunPlay_h_

#define PROGRAM "SunPlay"
#define VERSION	"v2r1  1999/06/14"

#include <libtsp.h>		/* p_ */
#include <libtsp/AFpar.h>	/* struct AF_NHpar */
#include <AO.h>			/* struct AO_FIpar */
#include <AD.h>			/* NOPORT */

#define AFPATH_ENV	"$AUDIOPATH"

#define SP_FIpar	AO_FIpar	/* Input file structure */

#define MAXFILE		50

struct SP_PlayOpt {
  const char *AudioDev;
  float Sfreq;
  int Wait_flag;
  int Nrepeat;
  float Pause[2];
};

#define PlayOpt_INIT(p) { \
	(p)->AudioDev = ""; \
	(p)->Sfreq = 0.0; \
	(p)->Wait_flag = 0; \
	(p)->Nrepeat = 1; \
	(p)->Pause[0] = 0.0; \
	(p)->Pause[1] = 0.0; }

/* Error messages */
#define SPM_BadPause	"Invalid pause value(s)"
#define SPM_BadRep	"Invalid number of repetitions"
#define SPM_LateFPar	"Input file parameter specified after input files"
#define SPM_LateDevPar	"Output port parameter specified after input files"
#define SPM_NoFName	"No filenames specified"
#define SPM_XFName	"Too many filenames specified"
#define SPM_XNChan	"Too many channels"

/* Printout formats */
#define SPMF_File	"File: %s\n"
#define SPMF_stdin	"File: <stdin>\n"

/* Usage */
#define SPMF_Usage "\
Usage: %s [options] File1 File2 ...\n\
Option:\n\
  -V VOL, --volume=VOL        Output port volume (0 to 100).\n\
  -b BAL, --balance=BAL       Output port stereo balance (0 to 100).\n\
  -p PORTS, --ports=PORTS     Ports, \"speaker\", \"headphone\", \"line-out\".\n\
  -l L:U, --limits=L:U        Frame limits.\n\
  -s SFREQ, --srate=SFREQ     Sampling rate for the output.\n\
  -r RPT, --repeat=RPT        Number of repetitions.\n\
  -B PAUSES, --pause=PAUSES   Inter-file and inter-repeat pauses.\n\
  -d DEV, --device=DEV        Audio device name.\n\
  -w, --wait                  Wait for the audio device.\n\
  -nw, --nowait               Do not wait for the audio device.\n\
  -g GAIN, --gain=GAIN        Gain factor applied to the input data.\n\
  -t FTYPE, --type=FTYPE      Input file type, \"auto\", \"AFsp\", \"WAVE\",\n\
                              \"AIFF\", \"noheader\", \"SPHERE\", \"ESPS\",\n\
                              \"IRCAM\", \"SPPACK\", \"INRS\", \"SPW\", \"text\".\n\
  -P PARMS, --parameters=PARMS  Parameters for headerless input files,\n\
                              \"Format,Start,Sfreq,Swapb,Nchan,ScaleF\".\n\
  -h, --help                  Print this message and exit.\n\
  -v, --version               Print the version number and exit."


#ifdef __cplusplus
extern "C" {
#endif

/* Prototypes */
void
SPoptions (int argc, const char *argv[], struct SP_PlayOpt *PlayOpt,
	   struct SP_FIpar FI[], struct AD_DevOpt DevOpt[],
	   int *Nfiles);

#ifdef __cplusplus
}
#endif

#endif /* SunPlay_h_ */
